Class: Imis::Api

Inherits:
Object
  • Object
show all
Defined in:
lib/imis/api.rb

Defined Under Namespace

Classes: PANELS

Constant Summary collapse

AUTHENTICATION_PATH =
'Token'
API_PATH =
'api'
QUERY_PATH =
'api/Query'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(skip_authentication: false) ⇒ Api

Returns a new instance of Api.



12
13
14
# File 'lib/imis/api.rb', line 12

def initialize(skip_authentication: false)
  authenticate unless skip_authentication
end

Instance Attribute Details

#imis_idObject

Returns the value of attribute imis_id.



10
11
12
# File 'lib/imis/api.rb', line 10

def imis_id
  @imis_id
end

#tokenObject (readonly)

Returns the value of attribute token.



10
11
12
# File 'lib/imis/api.rb', line 10

def token
  @token
end

#token_expirationObject (readonly)

Returns the value of attribute token_expiration.



10
11
12
# File 'lib/imis/api.rb', line 10

def token_expiration
  @token_expiration
end

Instance Method Details

#delete(business_object_name, url_id: nil) ⇒ Object

Remove a business object for the current member

Returns empty string on success



83
84
85
86
87
88
# File 'lib/imis/api.rb', line 83

def delete(business_object_name, url_id: nil)
  uri = uri_for(business_object_name, url_id: url_id)
  request = Net::HTTP::Delete.new(uri)
  result = submit(uri, authorize(request))
  result.body
end

#get(business_object_name, url_id: nil) ⇒ Object

Get a business object for the current member



43
44
45
46
47
48
# File 'lib/imis/api.rb', line 43

def get(business_object_name, url_id: nil)
  uri = uri_for(business_object_name, url_id: url_id)
  request = Net::HTTP::Get.new(uri)
  result = submit(uri, authorize(request))
  JSON.parse(result.body)
end

#imis_id_for(certificate) ⇒ Object

Convert a member’s certificate number into an iMIS ID number



24
25
26
27
# File 'lib/imis/api.rb', line 24

def imis_id_for(certificate)
  result = query(Imis.configuration.imis_id_query_name, { certificate: certificate })
  @imis_id = result['Items']['$values'][0]['ID']
end

#mapperObject



104
105
106
# File 'lib/imis/api.rb', line 104

def mapper
  @mapper ||= Mapper.new(self)
end

#panelsObject



108
109
110
111
112
# File 'lib/imis/api.rb', line 108

def panels
  @panels ||= PANELS.new(
    Panel::Vsc.new(self)
  )
end

#post(business_object_name, body, url_id: nil) ⇒ Object

Create a business object for the current member



71
72
73
74
75
76
77
# File 'lib/imis/api.rb', line 71

def post(business_object_name, body, url_id: nil)
  uri = uri_for(business_object_name, url_id: url_id)
  request = Net::HTTP::Post.new(uri)
  request.body = JSON.dump(body)
  result = submit(uri, authorize(request))
  JSON.parse(result.body)
end

#put(business_object_name, body, url_id: nil) ⇒ Object

Update a business object for the current member



61
62
63
64
65
66
67
# File 'lib/imis/api.rb', line 61

def put(business_object_name, body, url_id: nil)
  uri = uri_for(business_object_name, url_id: url_id)
  request = Net::HTTP::Put.new(uri)
  request.body = JSON.dump(body)
  result = submit(uri, authorize(request))
  JSON.parse(result.body)
end

#put_fields(business_object_name, fields, url_id: nil) ⇒ Object

Update only specific fields on a business object for the current member

fields - hash of shape: { field_name => new_value }


54
55
56
57
# File 'lib/imis/api.rb', line 54

def put_fields(business_object_name, fields, url_id: nil)
  updated = filter_fields(business_object_name, fields)
  put(business_object_name, updated, url_id: url_id)
end

#query(query_name, query_params = {}) ⇒ Object

Run an IQA Query

query_name   - the full path of the query in IQA, e.g. `$/_ABC/Fiander/iMIS_ID`
query_params - hash of shape: { param_name => param_value }


95
96
97
98
99
100
101
102
# File 'lib/imis/api.rb', line 95

def query(query_name, query_params = {})
  query_params[:QueryName] = query_name
  path = "#{QUERY_PATH}?#{query_params.to_query}"
  uri = URI(File.join(imis_hostname, path))
  request = Net::HTTP::Get.new(uri)
  result = submit(uri, authorize(request))
  JSON.parse(result.body)
end

#update(data) ⇒ Object



114
115
116
# File 'lib/imis/api.rb', line 114

def update(data)
  mapper.update(data)
end

#with(id, &block) ⇒ Object

Run requests as DSL, with specific iMIS ID only maintained for this scope

This should be used with methods that do not change the value of ‘imis_id`



33
34
35
36
37
38
39
# File 'lib/imis/api.rb', line 33

def with(id, &block)
  old_id = imis_id
  self.imis_id = id
  instance_eval(&block)
ensure
  self.imis_id = old_id
end