Class: Usps::Imis::Mapper
- Inherits:
-
Object
- Object
- Usps::Imis::Mapper
- Defined in:
- lib/usps/imis/mapper.rb
Overview
Specific known fields mapping to facilitate updating across multiple business objects.
Constant Summary collapse
- FIELD_MAPPING =
List of known mapped fields
{ grade: %w[ABC_ASC_Individual_Demog Grade], edpro: %w[ABC_ASC_Individual_Demog Educ_Proficiency], edach: %w[ABC_ASC_Individual_Demog Educ_Achievement], vessel_examiner: %w[ABC_ASC_Individual_Demog Vol_Vessel_Examiner], mm: %w[ABC_ASC_Individual_Demog TotMMS], mm_updated: %w[ABC_ASC_Individual_Demog MMS_Updated] }.freeze
Instance Attribute Summary collapse
-
#api ⇒ Object
readonly
The parent
Apiobject.
Instance Method Summary collapse
-
#initialize(api = nil, imis_id: nil) ⇒ Mapper
constructor
A new instance of
Mapper. -
#update(data) ⇒ Array<Usps::Imis::Data>
Update a member’s data on multiple affected business objects by arbitrary field names.
Constructor Details
Instance Attribute Details
#api ⇒ Object (readonly)
The parent Api object
22 23 24 |
# File 'lib/usps/imis/mapper.rb', line 22 def api @api end |
Instance Method Details
#update(data) ⇒ Array<Usps::Imis::Data>
Update a member’s data on multiple affected business objects by arbitrary field names
Does not require knowing which business object / iMIS-specific field name to use
Only available for fields defined in FIELD_MAPPING
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/usps/imis/mapper.rb', line 41 def update(data) updates = data.each_with_object({}) do |(field_key, value), hash| map_update(field_key) do |business_object_name, field| hash[business_object_name] ||= {} hash[business_object_name][field] = value end end updates.map do |business_object_name, field_updates| api.on(business_object_name).put_fields(field_updates) end end |