Module: Usps::Imis::CommandLine::Formatters
- Included in:
- Interface
- Defined in:
- lib/usps/imis/command_line/formatters.rb
Overview
Command line interface output formatters
Constant Summary collapse
- RAW_HASH_RESPONSE_OPTIONS =
CLI options that indicate the response is a raw Hash rather than a Data object, and should not be simplified
%i[business_objects auth_token].freeze