Exception: Usps::Imis::Error::ApiError
- Inherits:
-
StandardError
- Object
- StandardError
- Usps::Imis::Error::ApiError
- Defined in:
- lib/usps/imis/error/api_error.rb
Overview
Base error class for all internal exceptions
Direct Known Subclasses
Instance Attribute Summary collapse
-
#metadata ⇒ Object
Additional call-specific metadata to pass through to Bugsnag.
Instance Method Summary collapse
-
#bugsnag_meta_data ⇒ Hash
Additional metadata to include in Bugsnag reports.
-
#initialize(message, metadata = {}) ⇒ ApiError
constructor
A new instance of
ApiError.
Constructor Details
#initialize(message, metadata = {}) ⇒ ApiError
A new instance of ApiError
18 19 20 21 |
# File 'lib/usps/imis/error/api_error.rb', line 18 def initialize(, = {}) super() @metadata = end |
Instance Attribute Details
#metadata ⇒ Object
Additional call-specific metadata to pass through to Bugsnag
11 12 13 |
# File 'lib/usps/imis/error/api_error.rb', line 11 def @metadata end |
Instance Method Details
#bugsnag_meta_data ⇒ Hash
Additional metadata to include in Bugsnag reports
Can include fields at the top level, which will be shows on the custom tab
Can include fields nested under a top-level key, which will be shown on a tab with the top-level key as its name
32 33 34 |
# File 'lib/usps/imis/error/api_error.rb', line 32 def == {} ? {} : end |