Class: Usps::Imis::Mapper

Inherits:
Object
  • Object
show all
Defined in:
lib/usps/imis/mapper.rb

Constant Summary collapse

FIELD_MAPPING =
{
  vessel_examiner: %w[ABC_ASC_Individual_Demog Vol_Vessel_Examiner],
  mm: %w[ABC_ASC_Individual_Demog TotMMS],
  mm_updated: %w[ABC_ASC_Individual_Demog MMS_Updated]
}.freeze

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api = nil) ⇒ Mapper

Returns a new instance of Mapper.



14
15
16
# File 'lib/usps/imis/mapper.rb', line 14

def initialize(api = nil)
  @api = api || Api.new
end

Instance Attribute Details

#apiObject (readonly)

Returns the value of attribute api.



12
13
14
# File 'lib/usps/imis/mapper.rb', line 12

def api
  @api
end

Instance Method Details

#update(data) ⇒ Object

Update a member’s data on multiple affected business objects by arbitrary field names Does not require knowing which business object / iMIS-specific field name to use

Only available for previously-mapped fields

`data` is a hash of shape { field_key => value }


25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/usps/imis/mapper.rb', line 25

def update(data)
  updates = data.each_with_object({}) do |(field_key, value), hash|
    map_update(field_key) do |business_object_name, field|
      hash[business_object_name] ||= {}
      hash[business_object_name][field] = value
    end
  end

  updates.map do |business_object_name, field_updates|
    api.put_fields(business_object_name, field_updates)
  end
end